@@ -18,9 +18,17 @@ lav_fit_measures <- function(object, fit.measures="all",
         stop("lavaan ERROR: fit measures not available if model did not converge")
     }
 
+    TEST <- lavInspect(object, "test")
+
     # do we have a test statistic?
-    if(object@Fit@test[[1]]$test == "none") {
-        stop("lavaan ERROR: please refit the model with test=\"standard\"")
+    if(TEST[[1]]$test == "none") {
+
+        # to deal with semTools 0.4-9, we need to check the @Fit@test slot
+        if(object@Fit@test[[1]]$test != "none") {
+            TEST <- object@Fit@test
+        } else {
+            stop("lavaan ERROR: please refit the model with test=\"standard\"")
+        }
     }
 
     if("all" %in% fit.measures) {
@@ -61,8 +69,8 @@ lav_fit_measures <- function(object, fit.measures="all",
     estimator     <- object@Options$estimator
     test          <- object@Options$test
     G <- object@Data@ngroups  # number of groups
-    X2 <- object@Fit@test[[1]]$stat
-    df <- object@Fit@test[[1]]$df
+    X2 <- TEST[[1]]$stat
+    df <- TEST[[1]]$df
 
     # fit stat and df are NA (perhaps test="none"?), try again:
     if(is.na(df)) {
@@ -84,8 +92,8 @@ lav_fit_measures <- function(object, fit.measures="all",
 
     # scaled X2
     if(scaled) {
-        X2.scaled <- object@Fit@test[[2]]$stat
-        df.scaled <- object@Fit@test[[2]]$df
+        X2.scaled <- TEST[[2]]$stat
+        df.scaled <- TEST[[2]]$df
     }
 
     # define 'sets' of fit measures:
@@ -217,7 +225,7 @@ lav_fit_measures <- function(object, fit.measures="all",
 	indices["chisq"] <- X2
         if(scaled) {
             indices["chisq.scaled"] <- X2.scaled
-            indices["chisq.scaling.factor"] <- object@Fit@test[[2]]$scaling.factor
+            indices["chisq.scaling.factor"] <- TEST[[2]]$scaling.factor
         } 
     }
     if(any(c("df", "df.scaled") %in% fit.measures)) {
@@ -227,9 +235,9 @@ lav_fit_measures <- function(object, fit.measures="all",
         }
     }
     if(any(c("pvalue", "pvalue.scaled") %in% fit.measures)) {
-        indices["pvalue"] <- object@Fit@test[[1]]$pvalue
+        indices["pvalue"] <- TEST[[1]]$pvalue
         if(scaled) {
-            indices["pvalue.scaled"] <- object@Fit@test[[2]]$pvalue
+            indices["pvalue.scaled"] <- TEST[[2]]$pvalue
         }
     }
 
@@ -257,11 +265,11 @@ lav_fit_measures <- function(object, fit.measures="all",
                 X2.null.scaled <- df.null.scaled <- as.numeric(NA)
             }
         } else {
-            X2.null <- fit.indep@Fit@test[[1]]$stat
-            df.null <- fit.indep@Fit@test[[1]]$df
+            X2.null <- fit.indep@test[[1]]$stat
+            df.null <- fit.indep@test[[1]]$df
             if(scaled) {
-                X2.null.scaled <- fit.indep@Fit@test[[2]]$stat
-                df.null.scaled <- fit.indep@Fit@test[[2]]$df
+                X2.null.scaled <- fit.indep@test[[2]]$stat
+                df.null.scaled <- fit.indep@test[[2]]$df
             } 
         }
 
@@ -283,15 +291,15 @@ lav_fit_measures <- function(object, fit.measures="all",
                 }
             }
             if("baseline.pvalue" %in% fit.measures) {
-                indices["baseline.pvalue"] <- fit.indep@Fit@test[[1]]$pvalue
+                indices["baseline.pvalue"] <- fit.indep@test[[1]]$pvalue
                 if(scaled) {
                     indices["baseline.pvalue.scaled"] <- 
-                        fit.indep@Fit@test[[2]]$pvalue
+                        fit.indep@test[[2]]$pvalue
                 }
             }
             if("baseline.chisq.scaling.factor" %in% fit.measures) {
                 indices["baseline.chisq.scaling.factor"] <-
-                    fit.indep@Fit@test[[2]]$scaling.factor
+                    fit.indep@test[[2]]$scaling.factor
             }
 
             # CFI - comparative fit index (Bentler, 1990) 
@@ -477,7 +485,27 @@ lav_fit_measures <- function(object, fit.measures="all",
 
             # logl H1 -- unrestricted (aka saturated) model
             logl.H1.group <- numeric(G)
+
+            # check if everything is numeric, OR if we have exogenous
+            # factor with 2 levels only
+            logl.ok <- FALSE
             if(all(object@Data@ov$type == "numeric")) {
+                logl.ok <- TRUE
+            } else {
+                not.idx <- which(object@Data@ov$type != "numeric")
+                for(i in not.idx) {
+                    if(object@Data@ov$type[i] == "factor" &&
+                       object@Data@ov$exo[i] == 1L &&
+                       object@Data@ov$nlev[i] == 2L) {
+                        logl.ok <- TRUE
+                    } else {
+                        logl.ok <- FALSE
+                        break
+                    }
+                }
+            }
+
+            if(logl.ok) {
                 for(g in 1:G) {
                     nvar <- ncol(object@SampleStats@cov[[g]])
                     if(!object@SampleStats@missing.flag) {
@@ -512,7 +540,7 @@ lav_fit_measures <- function(object, fit.measures="all",
 
             # logl H0
             logl.H0.group <- numeric(G)
-            if(all(object@Data@ov$type == "numeric")) {
+            if(logl.ok) {
                 for(g in 1:G) {
                     Ng <- object@SampleStats@nobs[[g]]
                     logl.H0.group[g] <- -Ng * (fx.group[g] - 
@@ -554,9 +582,9 @@ lav_fit_measures <- function(object, fit.measures="all",
             # scaling factor for MLR
             if(object@Options$test == "yuan.bentler") {
                 indices["scaling.factor.h1"] <- 
-                    object@Fit@test[[2]]$scaling.factor.h1
+                    TEST[[2]]$scaling.factor.h1
                 indices["scaling.factor.h0"] <- 
-                    object@Fit@test[[2]]$scaling.factor.h0
+                    TEST[[2]]$scaling.factor.h0
             }
         } # ML
         else { # no ML!
@@ -582,7 +610,7 @@ lav_fit_measures <- function(object, fit.measures="all",
             RMSEA <- RMSEA.scaled <- as.numeric(NA)
         } else if(df > 0) {
             if(scaled) {
-                d <- sum(object@Fit@test[[2]]$trace.UGamma)
+                d <- sum(TEST[[2]]$trace.UGamma)
                 if(is.na(d) || d==0) d <- NA
             } 
             if(object@Options$mimic %in% c("Mplus", "lavaan")) {
@@ -638,7 +666,7 @@ lav_fit_measures <- function(object, fit.measures="all",
             df2 <- df
         } else {
             XX2 <- X2
-            df2 <- sum(object@Fit@test[[2]]$trace.UGamma)
+            df2 <- sum(TEST[[2]]$trace.UGamma)
         }
         lower.lambda <- function(lambda) {
             (pchisq(XX2, df=df2, ncp=lambda) - 0.95)
@@ -689,7 +717,7 @@ lav_fit_measures <- function(object, fit.measures="all",
             df2 <- df
         } else {
             XX2 <- X2
-            df2 <- sum(object@Fit@test[[2]]$trace.UGamma)
+            df2 <- sum(TEST[[2]]$trace.UGamma)
         }
         upper.lambda <- function(lambda) {
             (pchisq(XX2, df=df2, ncp=lambda) - 0.05)
@@ -738,7 +766,7 @@ lav_fit_measures <- function(object, fit.measures="all",
             df2 <- df
         } else {
             XX2 <- X2
-            df2 <- sum(object@Fit@test[[2]]$trace.UGamma)
+            df2 <- sum(TEST[[2]]$trace.UGamma)
         }
         if(is.na(XX2) || is.na(df2)) {
             indices["rmsea.pvalue.scaled"] <- as.numeric(NA)
