@@ -102,18 +102,60 @@ lavInspect <- function(lavobject,
               what == "samp" ||
               what == "sample" ||
               what == "samplestatistics") {
-        lav_object_inspect_sampstat(lavobject, 
+        lav_object_inspect_sampstat(lavobject, h1 = FALSE,
             add.labels = add.labels, add.class = add.class, 
             drop.list.single.group = drop.list.single.group)
+    } else if(what == "h1" || what == "missing.h1" || what == "sampstat.h1") {
+        lav_object_inspect_sampstat(lavobject, h1 = TRUE,
+            add.labels = add.labels, add.class = add.class,
+            drop.list.single.group = drop.list.single.group)
+
+    #### wls.est - wls.obs - wls.v ####
+    } else if(what == "wls.est") {
+        lav_object_inspect_wls_est(lavobject,
+            add.labels = add.labels, add.class = add.class,
+            drop.list.single.group = drop.list.single.group)
+    } else if(what == "wls.obs") {
+        lav_object_inspect_wls_obs(lavobject,
+            add.labels = add.labels, add.class = add.class,
+            drop.list.single.group = drop.list.single.group)
+    } else if(what == "wls.v") {
+        lav_object_inspect_wls_v(lavobject,
+            add.labels = add.labels, add.class = add.class,
+            drop.list.single.group = drop.list.single.group)
 
 
-    #### data ####
+
+    #### data + missingness ####
     } else if(what == "data") {
         lav_object_inspect_data(lavobject, 
             drop.list.single.group = drop.list.single.group)
     } else if(what == "case.idx") {
         lav_object_inspect_case_idx(lavobject,
             drop.list.single.group = drop.list.single.group) 
+    } else if(what == "ngroups") {
+        lavobject@Data@ngroups
+    } else if(what == "group") {
+        lavobject@Data@group
+    } else if(what == "group.label") {
+        lavobject@Data@group.label
+    } else if(what == "nobs") {
+        unlist( lavobject@Data@nobs )
+    } else if(what == "norig") {
+        unlist( lavobject@Data@norig )
+    } else if(what == "ntotal") {
+        sum(unlist( lavobject@Data@nobs ))
+    } else if(what == "coverage") {
+        lav_object_inspect_missing_coverage(lavobject,
+            add.labels = add.labels, add.class = add.class,
+            drop.list.single.group = drop.list.single.group)
+    } else if(what %in% c("patterns", "pattern")) {
+        lav_object_inspect_missing_patterns(lavobject,
+            add.labels = add.labels, add.class = add.class,
+            drop.list.single.group = drop.list.single.group)
+    } else if(what == "empty.idx") {
+        lav_object_inspect_empty_idx(lavobject,
+            drop.list.single.group = drop.list.single.group)
 
 
     #### rsquare ####
@@ -184,19 +226,6 @@ lavInspect <- function(lavobject,
  
 
 
-    #### missingness ####
-    } else if(what == "coverage") {
-        lav_object_inspect_missing_coverage(lavobject,
-            add.labels = add.labels, add.class = add.class,
-            drop.list.single.group = drop.list.single.group)
-    } else if(what %in% c("patterns", "pattern")) {
-        lav_object_inspect_missing_patterns(lavobject,
-            add.labels = add.labels, add.class = add.class,
-            drop.list.single.group = drop.list.single.group)
-    } else if(what == "empty.idx") {
-        lav_object_inspect_empty_idx(lavobject,
-            drop.list.single.group = drop.list.single.group)
-
     #### convergence, meanstructure, categorical ####
     } else if(what == "converged") {
         lavobject@Fit@converged
@@ -208,24 +237,13 @@ lavInspect <- function(lavobject,
         lavobject@Model@meanstructure
     } else if(what == "categorical") {
         lavobject@Model@categorical
+    } else if(what == "fixed.x") {
+        lavobject@Model@fixed.x
+    } else if(what == "parameterization") {
+        lavobject@Model@parameterization
     
 
 
-    #### wls.est - wls.obs - wls.v ####
-    } else if(what == "wls.est") {
-        lav_object_inspect_wls_est(lavobject,
-            add.labels = add.labels, add.class = add.class,
-            drop.list.single.group = drop.list.single.group)
-    } else if(what == "wls.obs") {
-        lav_object_inspect_wls_obs(lavobject,
-            add.labels = add.labels, add.class = add.class,
-            drop.list.single.group = drop.list.single.group)
-    } else if(what == "wls.v") {
-        lav_object_inspect_wls_v(lavobject,
-            add.labels = add.labels, add.class = add.class,
-            drop.list.single.group = drop.list.single.group)
-
-
     #### NACOV samplestats ####
     } else if(what == "gamma") {
         lav_object_inspect_sampstat_gamma(lavobject,
@@ -336,6 +354,26 @@ lavInspect <- function(lavobject,
     } else if(what == "post.check" || what == "post") {
         lav_object_post_check(lavobject)
 
+    # options
+    } else if(what == "options" || what == "lavoptions") {
+        lavobject@Options
+
+    # call
+    } else if(what == "call") {
+        as.list( lavobject@call )
+
+    # timing
+    } else if(what == "timing") {
+        lavobject@timing
+
+    # optim
+    } else if(what == "optim") {
+        lavobject@optim
+
+    # test
+    } else if(what == "test") {
+        lavobject@test
+
     #### not found ####
     } else {
         stop("unknown `what' argument in inspect function: `", what, "'")
@@ -513,7 +551,7 @@ lav_object_inspect_modelmatrices <- function(lavobject, what = "free",
 
 
 # fixme, should we export this function?
-lav_object_inspect_sampstat <- function(lavobject, 
+lav_object_inspect_sampstat <- function(lavobject, h1 = FALSE,
     add.labels = FALSE, add.class = FALSE, drop.list.single.group = FALSE) {
 
     G <- lavobject@Data@ngroups
@@ -521,7 +559,13 @@ lav_object_inspect_sampstat <- function(lavobject,
 
     OUT <- vector("list", length=G)
     for(g in 1:G) {
-        OUT[[g]]$cov  <- lavobject@SampleStats@cov[[g]]
+
+        # covariance matrix
+        if(h1 && !is.null(lavobject@SampleStats@missing.h1[[g]])) {
+            OUT[[g]]$cov  <- lavobject@SampleStats@missing.h1[[g]]$sigma
+        } else {
+            OUT[[g]]$cov  <- lavobject@SampleStats@cov[[g]]
+        }
         if(add.labels) {
             rownames(OUT[[g]]$cov) <- colnames(OUT[[g]]$cov) <- ov.names[[g]]
         }
@@ -529,16 +573,20 @@ lav_object_inspect_sampstat <- function(lavobject,
             class(OUT[[g]]$cov) <- c("lavaan.matrix.symmetric", "matrix")
         }
 
-        #if(lavobject@Model@meanstructure) {
+        # mean vector
+        if(h1 && !is.null(lavobject@SampleStats@missing.h1[[g]])) {
+            OUT[[g]]$mean <- lavobject@SampleStats@missing.h1[[g]]$mu
+        } else {
             OUT[[g]]$mean <- as.numeric(lavobject@SampleStats@mean[[g]])
-            if(add.labels) {
-                names(OUT[[g]]$mean) <- ov.names[[g]]
-            }
-            if(add.class) {
-                class(OUT[[g]]$mean) <- c("lavaan.vector", "numeric")
-            }
-        #}
+        }
+        if(add.labels) {
+            names(OUT[[g]]$mean) <- ov.names[[g]]
+        }
+        if(add.class) {
+            class(OUT[[g]]$mean) <- c("lavaan.vector", "numeric")
+        }
 
+        # thresholds
         if(lavobject@Model@categorical) {
             OUT[[g]]$th <- as.numeric(lavobject@SampleStats@th[[g]])
             if(length(lavobject@Model@num.idx[[g]]) > 0L) {
@@ -553,6 +601,7 @@ lav_object_inspect_sampstat <- function(lavobject,
             }
         }
 
+        # slopes
         if(lavobject@Model@categorical &&
            lavobject@Model@nexo > 0L) {
             OUT[[g]]$slopes  <- lavobject@SampleStats@slopes[[g]]
@@ -566,6 +615,7 @@ lav_object_inspect_sampstat <- function(lavobject,
             }
         }
 
+        # stochastic weights
         if(lavobject@Model@group.w.free) {
             OUT[[g]]$group.w <- lavobject@SampleStats@group.w[[g]]
             if(add.labels) {
@@ -630,7 +680,6 @@ lav_object_inspect_case_idx <- function(lavobject,
 }
 
 
-
 lav_object_inspect_rsquare <- function(lavobject, est.std.all=NULL,
     add.labels = FALSE, add.class = FALSE, drop.list.single.group = FALSE) {
 
@@ -1328,7 +1377,7 @@ lav_object_inspect_firstorder <- function(lavobject,
 
 lav_object_inspect_vcov <- function(lavobject, standardized = FALSE,
     type = "std.all", free.only = TRUE,
-    add.labels = FALSE, add.class = FALSE) {
+    add.labels = FALSE, add.class = FALSE, remove.duplicated = FALSE) {
 
     if(lavobject@Fit@npar == 0) {
         OUT <- matrix(0,0,0)
@@ -1398,6 +1447,17 @@ lav_object_inspect_vcov <- function(lavobject, standardized = FALSE,
             lav_partable_labels(lavobject@ParTable, type="free")
     }
 
+    # alias?
+    if(remove.duplicated) {
+        simple.flag <- lav_constraints_check_simple(lavobject@Model)
+        if(simple.flag) {
+          K <- lav_constraints_R2K(lavobject@Model)
+          OUT <- t(K) %*% OUT %*% K
+      } else {
+          warning("lavaan WARNING: alias is TRUE, but equality constraints do not appear to be simple; returning full vcov")
+      }
+    }
+
     # class
     if(add.class) {
         class(OUT) <- c("lavaan.matrix.symmetric", "matrix")
@@ -1491,3 +1551,4 @@ lav_object_inspect_UGamma <- function(lavobject,
 
     OUT
 }
+
