@@ -246,6 +246,7 @@ lav_model_test <- function(lavmodel       = NULL,
         }
     }
 
+
     if(test == "none" || df < 0L || estimator == "MML") {
         TEST[[1]] <- list(test=test,
                           stat=as.numeric(NA),
@@ -341,6 +342,15 @@ lav_model_test <- function(lavmodel       = NULL,
         return(TEST)
     }
 
+    # do we already know E.inv is singular?
+    E.inv <- attr(VCOV, "E.inv")
+    if(!is.null(E.inv) && inherits(E.inv, "try-error")) {
+        TEST[[2]] <- list(test=test, stat=chisq, stat.group=chisq.group,
+                          df=df, refdistr=refdistr, pvalue=pvalue,
+                          scaling.factor=as.numeric(NA))
+        return(TEST)
+    }
+
     # some require meanstructure (for now)
     if(test %in% c("satorra.bentler", "yuan.bentler") &&
        !lavoptions$meanstructure) {
@@ -529,6 +539,15 @@ lav_model_test <- function(lavmodel       = NULL,
                                            inverted       = TRUE)
         }
 
+        if(inherits(E.inv, "try-error")) {
+            TEST[[2]] <- list(test=test, stat=as.numeric(NA),
+                stat.group=rep(as.numeric(NA), lavsamplestats@ngroups),
+                df=df, refdistr=refdistr, pvalue=as.numeric(NA),
+                scaling.factor=as.numeric(NA))
+            warning("lavaan WARNING: could not compute scaled test statistic\n")
+            return(TEST)
+        }
+
         if(mimic == "Mplus" || mimic == "lavaan") {
             if(is.null(B0.group)) {
                 B0 <- 
